Crate bevy_blacklight_material

Crate bevy_blacklight_material 

A plugin for the bevy engine providing a simple BlacklightMaterial, which reveals a base color based on light data from spot lights tagged with a Blacklight component.

Possible future features:

  • StandardMaterial extension for a “blacklight mapped” material.
  • Point light support.

Structs

Blacklight
Marker component for spot lights to use them as blacklights for BlacklightMaterial.
BlacklightData
Shader data representing a single blacklight point light.
BlacklightMaterial
Material which is invisible until exposed to light from a spot light tagged with the Blacklight component.
BlacklightPlugin
Plugin which enables and updates blacklight shaders.