A plugin for the bevy engine providing a simple BlacklightMaterial, which reveals a base
color based on light data from spot lights tagged with a Blacklight component.
Possible future features:
StandardMaterialextension for a “blacklight mapped” material.- Point light support.
Structs
- Blacklight
- Marker component for spot lights to use them as blacklights for
BlacklightMaterial. - Blacklight
Data - Shader data representing a single blacklight point light.
- Blacklight
Material - Material which is invisible until exposed to light from a spot light tagged with the
Blacklightcomponent. - Blacklight
Plugin - Plugin which enables and updates blacklight shaders.